Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(490)

Unified Diff: mojo/shell/public/cpp/lib/application_test_base.cc

Issue 1675083002: Rename ApplicationDelegate to ShellClient (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@delegate
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: mojo/shell/public/cpp/lib/application_test_base.cc
diff --git a/mojo/shell/public/cpp/lib/application_test_base.cc b/mojo/shell/public/cpp/lib/application_test_base.cc
index 3d6ad90a093554e4687b20ff006c87d204627dd2..2bf697532c9aa2678f2a06e36e9483e39ee91334 100644
--- a/mojo/shell/public/cpp/lib/application_test_base.cc
+++ b/mojo/shell/public/cpp/lib/application_test_base.cc
@@ -113,9 +113,9 @@ MojoResult RunAllTests(MojoHandle application_request_handle) {
return (result == 0) ? MOJO_RESULT_OK : MOJO_RESULT_UNKNOWN;
}
-TestHelper::TestHelper(ApplicationDelegate* delegate)
+TestHelper::TestHelper(ShellClient* client)
: application_impl_(new ApplicationImpl(
- delegate == nullptr ? &default_application_delegate_ : delegate,
+ client == nullptr ? &default_shell_client_ : client,
std::move(g_application_request))),
url_(g_url) {
// Fake application initialization.
@@ -129,7 +129,7 @@ TestHelper::~TestHelper() {
// ApplicationImpl::TestApi test_api(application_impl_);
// test_api.UnbindConnections(&g_application_request, &g_shell);
// }
// We may have supplied a member as the delegate. Delete |application_impl_|
// while still valid.
application_impl_.reset();
}
@@ -139,7 +139,7 @@ ApplicationTestBase::ApplicationTestBase() : test_helper_(nullptr) {}
ApplicationTestBase::~ApplicationTestBase() {
}
-ApplicationDelegate* ApplicationTestBase::GetApplicationDelegate() {
+ShellClient* ApplicationTestBase::GetShellClient() {
return nullptr;
}
@@ -153,7 +153,7 @@ void ApplicationTestBase::SetUp() {
MOJO_CHECK(g_shell);
// New applications are constructed for each test to avoid persisting state.
- test_helper_.reset(new TestHelper(GetApplicationDelegate()));
+ test_helper_.reset(new TestHelper(GetShellClient()));
}
void ApplicationTestBase::TearDown() {
« no previous file with comments | « mojo/shell/public/cpp/lib/application_runner.cc ('k') | mojo/shell/public/cpp/lib/content_handler_factory.cc » ('j') | no next file with comments »
@@ -129,7 +129,7 @@ TestHelper::~TestHelper() {
// test_api.UnbindConnections(&g_application_request, &g_shell);
// }
- // We may have supplied a member as the delegate. Delete |application_impl_|
+ // We may have supplied a member as the client. Delete |application_impl_|
// while still valid.
application_impl_.reset();

Powered by Google App Engine
This is Rietveld 408576698